==> with-component-state-3.0.1.tgz: package/person/createWithComponentState.js <==
import React, {PureComponent} from 'react'
import {connect} from 'react-redux'

import createActions from './createActions'
import getDisplayName from './getDisplayName'

const empty = {}

export default function createWithComponentState ({prefix, reducers}) {
  return function withComponentState () {
    return WrappedComponent => {
      const DEFAULT_ID = 'default'

      const name = getDisplayName(WrappedComponent)

      // TODO ick
      let id = DEFAULT_ID

      class WithComponentState extends PureComponent {
        constructor (props) {
          super(props)
          this.setId = this.setId.bind(this)
          this.setComponentState = this.setComponentState.bind(this)
          this.setId()
        }

        setId () {
          id = this.props.componentStateId || DEFAULT_ID
        }

        componentDidUpdate (prevProps) {
          const prevId = prevProps.componentStateId

          const {
            componentStateId,
            remove
          } = this.props

          if (prevId === componentStateId) return

          remove({name, id: componentStateId})

          this.setId()
        }

        componentWillUnmount () {
          this.props.remove({name, id})
        }

        setComponentState (state) {
          return this.props.setState({
            name,
            id,
            state
          })
        }

        render () {
          return (
            <WrappedComponent
              {...this.props}
              setState={this.setComponentState}
            />
          )
        }
      }

      WithComponentState.WrappedComponent = WrappedComponent

      WithComponentState.displayName = `WithComponentState(${name})`

      function mapStateToProps (state) {
        const currentId = id || DEFAULT_ID
        const {
          [prefix]: {
            [name]: {
              [currentId]: componentState = empty
            } = empty
          } = empty
        } = state

        return {componentState}
      }

      const mapDispatchToProps = createActions(prefix)

      return connect(mapStateToProps, mapDispatchToProps)(WithComponentState)
    }
  }
}

==> with-component-state-3.0.5.tgz: package/person/createWithComponentState.js <==
import React, {PureComponent} from 'react'
import {connect} from 'react-redux'

import createActions from './createActions'
import getDisplayName from './getDisplayName'

const empty = {}

export default function createWithComponentState ({prefix, reducers}) {
  return function withComponentState () {
    return WrappedComponent => {
      const DEFAULT_ID = 'default'

      const name = getDisplayName(WrappedComponent)

      class WithComponentState extends PureComponent {
        constructor (props) {
          super(props)
          this.setComponentState = this.setComponentState.bind(this)
        }

        get id () {
          return this.props.componentStateId || DEFAULT_ID
        }

        componentDidUpdate (prevProps) {
          const prevId = prevProps.componentStateId

          const {
            remove,
            componentStateId
          } = this.props

          if (prevId === componentStateId) return

          remove({
            name,
            id: this.id
          })
        }

        componentWillUnmount () {
          this.props.remove({
            name,
            id: this.id
          })
        }

        setComponentState (state) {
          return this.props.setState({
            name,
            id: this.id,
            state
          })
        }

        render () {
          const {
            componentState
          } = this.props

          const props = Object.assign({}, this.props)

          delete props.componentState
          delete props.componentStateId

          return (
            <WrappedComponent
              {...props}
              componentState={componentState[this.id] || empty}
              setState={this.setComponentState}
            />
          )
        }
      }

      WithComponentState.WrappedComponent = WrappedComponent

      WithComponentState.displayName = `WithComponentState(${name})`

      function mapStateToProps (state) {
        const {
          [prefix]: {
            [name]: componentState = empty
          } = empty
        } = state

        return {componentState}
      }

      const mapDispatchToProps = createActions(prefix)

      return connect(mapStateToProps, mapDispatchToProps)(WithComponentState)
    }
  }
}
